Module float

Module float 

Float compression schemes.

Structs

ALPRDScheme
ALPRD (ALP with Real Double) encoding variant.
ALPScheme
ALP (Adaptive Lossless floating-Point) encoding.
FloatConstantScheme
Constant encoding for float arrays with a single distinct value.
FloatDictScheme
Dictionary encoding for low-cardinality float values.
FloatRLEScheme
RLE scheme for float arrays.
FloatStats
Array of floating-point numbers and relevant stats for compression.
NullDominatedSparseScheme
Sparse encoding for null-dominated float arrays.

Functions

is_float_primitive
Returns true if the canonical form represents a floating-point primitive.