Module integer

Module integer 

Integer compression schemes.

Structs

BitPackingScheme
BitPacking encoding for non-negative integers.
FoRScheme
Frame of Reference encoding.
IntConstantScheme
Constant encoding for integer arrays with a single distinct value.
IntDictScheme
Dictionary encoding for low-cardinality integer values.
IntRLEScheme
RLE scheme for integer arrays.
IntegerStats
Array of integers and relevant stats for compression.
RunEndScheme
Run-end encoding with end positions.
SequenceScheme
Sequence encoding for sequential patterns.
SparseScheme
Sparse encoding for single-value-dominated arrays.
ZigZagScheme
ZigZag encoding for negative integers.

Functions

is_integer_primitive
Returns true if the canonical array is a primitive with an integer ptype.