Module string

Module string 

String compression schemes.

Structs

FSSTScheme
FSST (Fast Static Symbol Table) compression.
NullDominatedSparseScheme
Sparse encoding for null-dominated arrays.
StringConstantScheme
Constant encoding for string arrays with a single distinct value.
StringDictScheme
Dictionary encoding for low-cardinality string values.
StringStats
Array of variable-length byte arrays, and relevant stats for compression.

Functions

is_utf8_string
Returns true if the canonical array is a UTF-8 string type.