Integer compression schemes.
Structs
- BitPacking
Scheme - BitPacking encoding for non-negative integers.
- FoRScheme
- Frame of Reference encoding.
- IntConstant
Scheme - Constant encoding for integer arrays with a single distinct value.
- IntDict
Scheme - Dictionary encoding for low-cardinality integer values.
- IntRLE
Scheme - RLE scheme for integer arrays.
- Integer
Stats - Array of integers and relevant stats for compression.
- RunEnd
Scheme - Run-end encoding with end positions.
- Sequence
Scheme - Sequence encoding for sequential patterns.
- Sparse
Scheme - Sparse encoding for single-value-dominated arrays.
- ZigZag
Scheme - ZigZag encoding for negative integers.
Functions
- is_
integer_ primitive - Returns
trueif the canonical array is a primitive with an integer ptype.